@@ -38,6 +38,11 @@ urlpatterns = patterns("tendenci.addons.memberships.views",
         "membership_default_import_check_preprocess_status",
         name="memberships.default_import_check_preprocess_status"),
 
+    # export membership default
+    url(r"^export/$",
+        "membership_default_export",
+        name="memberships.default_export"),
+
     url(r"^get_app_fields/$",
         "get_app_fields_json",
         name="memberships.get_app_fields"),
