@@ -13,6 +13,7 @@ from tendenci.core.base.http import Http403
 from tendenci.core.perms.utils import has_perm
 from tendenci.core.event_logs.models import EventLog
 from tendenci.core.theme.utils import get_theme, theme_choices as theme_choice_list
+from tendenci.libs.boto_s3.utils import delete_file_from_s3
 from tendenci.apps.theme_editor.models import ThemeFileVersion
 from tendenci.apps.theme_editor.forms import FileForm, ThemeSelectForm, UploadForm
 from tendenci.apps.theme_editor.utils import get_dir_list, get_file_list, get_file_content, get_all_files_list
@@ -228,15 +229,7 @@ def copy_to_theme(request, app=None):
 
     messages.add_message(request, messages.SUCCESS, ('Successfully copied %s/%s to the the theme root' % (current_dir, chosen_file)))
 
-    log_defaults = {
-        'event_id': 1110200,
-        'event_data': '%s copied by %s' % (full_filename, request.user),
-        'description': 'theme file copied to theme',
-        'user': request.user,
-        'request': request,
-        'source': 'theme_editor',
-    }
-    EventLog.objects.log(**log_defaults)
+    EventLog.objects.log()
     return redirect('theme_editor.editor')
 
 
@@ -274,17 +267,12 @@ def delete_file(request):
 
     os.remove(full_filename)
 
+    if settings.USE_S3_STORAGE:
+        delete_file_from_s3(file=settings.AWS_LOCATION + '/' + 'themes/' + get_theme() + '/' + current_dir + chosen_file)
+
     messages.add_message(request, messages.SUCCESS, ('Successfully deleted %s/%s.' % (current_dir, chosen_file)))
 
-    log_defaults = {
-        'event_id': 1110300,
-        'event_data': '%s deleted by %s' % (full_filename, request.user),
-        'description': 'theme file deleted',
-        'user': request.user,
-        'request': request,
-        'source': 'theme_editor',
-    }
-    EventLog.objects.log(**log_defaults)
+    EventLog.objects.log()
     return redirect('theme_editor.editor')
 
 def upload_file(request):
@@ -310,15 +298,7 @@ def upload_file(request):
                 }
                 messages.add_message(request, messages.SUCCESS, ('Successfully uploaded %s.' % (upload.name)))
 
-                log_defaults = {
-                    'event_id': 1110100,
-                    'event_data': '%s uploaded by %s' % (full_filename, request.user),
-                    'description': 'theme file upload',
-                    'user': request.user,
-                    'request': request,
-                    'source': 'theme_editor',
-                }
-                EventLog.objects.log(**log_defaults)
+                EventLog.objects.log()
 
                 return HttpResponseRedirect('/theme-editor/editor/')
     else:
